==> EdSurvey_3.0.1.tar.gz: EdSurvey/tests/testthat/REF-2-esdfl.R <==
et1REF <- c("",
            "Formula: composite ~ b017451 + dsex ",
            "",
            "Plausible values: 5", 
            "jrrIMax: 1",
            "Weight variable: 'origwt'",
            "Variance method: jackknife", 
            "JK replicates: 62",
            "",
            "Summary Table:",
            "      labels              b017451   dsex  N   WTD_N      PCT   SE(PCT)     MEAN  SE(MEAN)", 
            " A locations Never or hardly ever   Male 10 12.5827 49.06722  7.569623 277.1902  9.653659", 
            " A locations Never or hardly ever Female  9 13.0611 50.93278  7.569623 269.0378  3.584617", 
            " A locations Once every few weeks   Male  8 11.9129 43.99313  3.765086 302.6347  7.582450", 
            " A locations Once every few weeks Female  9 15.1661 56.00687  3.765086 257.9601  4.481766", 
            " A locations    About once a week   Male  5  8.1332 59.85884  3.445449 293.3988  9.217647", 
            " A locations    About once a week Female  4  5.4541 40.14116  3.445449 278.7797  8.946966", 
            " A locations  2 or 3 times a week   Male 11 12.8220 54.36114  5.960610 304.0592 10.285774", 
            " A locations  2 or 3 times a week Female  8 10.7647 45.63886  5.960610 291.0742  8.317934", 
            " A locations            Every day   Male 10 14.4485 68.95013  8.842419 296.7421  4.481794", 
            " A locations            Every day Female  5  6.5065 31.04987  8.842419 324.2656  9.102156", 
            " B locations Never or hardly ever   Male 13 21.6725 77.43608 19.962898 295.0064 15.598551", 
            " B locations Never or hardly ever Female  6  6.3151 22.56392 19.962898 274.6031 10.344199", 
            " B locations Once every few weeks   Male 13 18.3234 76.14318  2.156025 278.5435 18.844505", 
            " B locations Once every few weeks Female  4  5.7410 23.85682  2.156025 292.0952 17.100752", 
            " B locations    About once a week   Male  3  4.7842 34.60192 11.172614 266.4076 18.080846", 
            " B locations    About once a week Female  7  9.0422 65.39808 11.172614 295.1116 20.765073", 
            " B locations  2 or 3 times a week   Male  8 12.9172 52.83735  7.772479 306.8860 28.172189", 
            " B locations  2 or 3 times a week Female  8 11.5299 47.16265  7.772479 297.9851 23.493089", 
            " B locations            Every day   Male  6  9.3770 41.79108  3.040740 304.2102 20.168767", 
            " B locations            Every day Female  8 13.0608 58.20892  3.040740 307.8255 16.584912", 
            " C locations Never or hardly ever   Male  6 10.8124 47.77969  8.112159 304.4941 39.497299", 
            " C locations Never or hardly ever Female  9 11.8173 52.22031  8.112159 284.6628  5.950336", 
            " C locations Once every few weeks   Male  6  7.7506 71.68119 13.890589 278.6115 42.656759", 
            " C locations Once every few weeks Female  4  3.0620 28.31881 13.890589 274.2946  8.732438", 
            " C locations    About once a week   Male  3  5.3106 31.98848  5.364911 293.3708 10.919791", 
            " C locations    About once a week Female  8 11.2910 68.01152  5.364911 313.0450 10.417147", 
            " C locations  2 or 3 times a week   Male  5  6.3631 47.50000  5.421088 284.3908  9.818138", 
            " C locations  2 or 3 times a week Female  5  7.0329 52.50000  5.421088 283.9222 11.715445", 
            " C locations            Every day   Male  7 10.4298 40.97767  5.230350 270.0470  7.455640", 
            " C locations            Every day Female  8 15.0226 59.02233  5.230350 296.9268  7.723949", 
            " D locations Never or hardly ever   Male  6  8.8988 29.06291  7.187947 278.8668 48.293835", 
            " D locations Never or hardly ever Female 11 21.7203 70.93709  7.187947 284.2274 11.060203", 
            " D locations Once every few weeks   Male  9 18.6586 61.90500  7.942009 289.6432 42.618475", 
            " D locations Once every few weeks Female  7 11.4821 38.09500  7.942009 296.3440 38.942394", 
            " D locations    About once a week   Male  6  5.5978 28.32995  9.538735 262.6206 12.639561", 
            " D locations    About once a week Female  9 14.1615 71.67005  9.538735 272.2270 15.980306", 
            " D locations  2 or 3 times a week   Male 12 19.6157 39.92254 11.538978 302.2271 36.999592", 
            " D locations  2 or 3 times a week Female 17 29.5187 60.07746 11.538978 281.6134 24.967995", 
            " D locations            Every day   Male  7  9.2338 32.06025  9.061170 275.6733 36.000387", 
            " D locations            Every day Female 12 19.5676 67.93975  9.061170 268.9318  8.698796"
)

et2REF <- c("",
            "Formula: composite ~ b017451 ",
            "",
            "Plausible values: 5", 
            "jrrIMax: 1",
            "Weight variable: 'origwt'",
            "Variance method: jackknife", 
            "JK replicates: 62",
            "",
            "Summary Table:",
            "             labels              b017451  N WTD_N PCT", 
            "  first E locations Never or hardly ever NA    NA  NA",
            "  first E locations Once every few weeks NA    NA  NA",
            "  first E locations    About once a week NA    NA  NA",
            "  first E locations  2 or 3 times a week NA    NA  NA",
            "  first E locations            Every day NA    NA  NA",
            "        B locations Never or hardly ever 19    28  25",
            "        B locations Once every few weeks 17    24  21", 
            "        B locations    About once a week 10    14  12",
            "        B locations  2 or 3 times a week 16    24  22", 
            "        B locations            Every day 14    22  20",
            "        C locations Never or hardly ever 15    23  25", 
            "        C locations Once every few weeks 10    11  12",
            "        C locations    About once a week 11    17  19", 
            "        C locations  2 or 3 times a week 10    13  15",
            "        C locations            Every day 15    25  29",
            " second E locations Never or hardly ever NA    NA  NA",
            " second E locations Once every few weeks NA    NA  NA",
            " second E locations    About once a week NA    NA  NA",
            " second E locations  2 or 3 times a week NA    NA  NA",
            " second E locations            Every day NA    NA  NA"
)

printREF <- c("an edsurvey.data.frame.list with 4 elements",
              "covs:",
              "       labels",
              "1 A locations",
              "2 B locations",
              "3 C locations",
              "4 D locations",
              "",
              "",
              "Element 1",
              "edsurvey.data.frame for 2005 NAEP (Mathematics) in USA",
              "Dimensions: 46 rows and 303 columns.",
              "",
              "There is 1 full sample weight in this edsurvey.data.frame:",
              "  'origwt' with 62 JK replicate weights (the default).",
              "",
              "",
              "There are 6 subject scale(s) or subscale(s) in this edsurvey.data.frame:",
              "'num_oper' subject scale or subscale with 5 plausible values.",
              "",
              "'measurement' subject scale or subscale with 5 plausible values.",
              "",
              "'geometry' subject scale or subscale with 5 plausible values.",
              "",
              "'data_anal_prob' subject scale or subscale with 5 plausible values.",
              "",
              "'algebra' subject scale or subscale with 5 plausible values.",
              "",
              "'composite' subject scale or subscale with 5 plausible values (the default).",
              "",
              "",
              "Omitted Levels: 'Multiple', 'NA', and 'Omitted'",
              "",
              "User Conditions:",
              "scrpsu %in% c(\"5\", \"45\", \"56\") dsex == \"Male\"",
              "",
              "Default Conditions:",
              "tolower(rptsamp) == \"reporting sample\"",
              "Achievement Levels:",
              "Mathematics:",
              "Basic: 262.00",
              "Proficient: 299.00",
              "Advanced: 333.00",
              "",
              "",
              "Element 2",
              "edsurvey.data.frame for 2002 NAEP (Mathematics) in USA",
              "Dimensions: 46 rows and 303 columns.",
              "",
              "There is 1 full sample weight in this edsurvey.data.frame:",
              "  'origwt' with 62 JK replicate weights (the default).",
              "",
              "",
              "There are 6 subject scale(s) or subscale(s) in this edsurvey.data.frame:",
              "'num_oper' subject scale or subscale with 5 plausible values.",
              "",
              "'measurement' subject scale or subscale with 5 plausible values.",
              "",
              "'geometry' subject scale or subscale with 5 plausible values.",
              "",
              "'data_anal_prob' subject scale or subscale with 5 plausible values.",
              "",
              "'algebra' subject scale or subscale with 5 plausible values.",
              "",
              "'composite' subject scale or subscale with 5 plausible values (the default).",
              "",
              "",
              "Omitted Levels: 'Multiple', 'NA', and 'Omitted'",
              "",
              "User Conditions:",
              "scrpsu %in% c(\"75\", \"76\", \"78\") dsex == \"Male\"",
              "",
              "Default Conditions:",
              "tolower(rptsamp) == \"reporting sample\"",
              "Achievement Levels:",
              "Mathematics:",
              "Basic: 262.00",
              "Proficient: 299.00",
              "Advanced: 333.00",
              "",
              "",
              "Element 3",
              "edsurvey.data.frame for 2003 NAEP (Mathematics) in USA",
              "Dimensions: 28 rows and 303 columns.",
              "",
              "There is 1 full sample weight in this edsurvey.data.frame:",
              "  'origwt' with 62 JK replicate weights (the default).",
              "",
              "",
              "There are 6 subject scale(s) or subscale(s) in this edsurvey.data.frame:",
              "'num_oper' subject scale or subscale with 5 plausible values.",
              "",
              "'measurement' subject scale or subscale with 5 plausible values.",
              "",
              "'geometry' subject scale or subscale with 5 plausible values.",
              "",
              "'data_anal_prob' subject scale or subscale with 5 plausible values.",
              "",
              "'algebra' subject scale or subscale with 5 plausible values.",
              "",
              "'composite' subject scale or subscale with 5 plausible values (the default).",
              "",
              "",
              "Omitted Levels: 'Multiple', 'NA', and 'Omitted'",
              "",
              "User Conditions:",
              "scrpsu %in% 100:200 dsex == \"Male\"",
              "",
              "Default Conditions:",
              "tolower(rptsamp) == \"reporting sample\"",
              "Achievement Levels:",
              "Mathematics:",
              "Basic: 262.00",
              "Proficient: 299.00",
              "Advanced: 333.00",
              "",
              "",
              "Element 4",
              "edsurvey.data.frame for 2005 NAEP (Mathematics) in USA",
              "Dimensions: 43 rows and 303 columns.",
              "",
              "There is 1 full sample weight in this edsurvey.data.frame:",
              "  'origwt' with 62 JK replicate weights (the default).",
              "",
              "",
              "There are 6 subject scale(s) or subscale(s) in this edsurvey.data.frame:",
              "'num_oper' subject scale or subscale with 5 plausible values.",
              "",
              "'measurement' subject scale or subscale with 5 plausible values.",
              "",
              "'geometry' subject scale or subscale with 5 plausible values.",
              "",
              "'data_anal_prob' subject scale or subscale with 5 plausible values.",
              "",
              "'algebra' subject scale or subscale with 5 plausible values.",
              "",
              "'composite' subject scale or subscale with 5 plausible values (the default).",
              "",
              "",
              "Omitted Levels: 'Multiple', 'NA', and 'Omitted'",
              "",
              "User Conditions:",
              "scrpsu %in% 201:300 dsex == \"Male\"",
              "",
              "Default Conditions:",
              "tolower(rptsamp) == \"reporting sample\"",
              "Achievement Levels:",
              "Mathematics:",
              "Basic: 262.00",
              "Proficient: 299.00",
              "Advanced: 333.00"
              )

==> EdSurvey_3.1.0.tar.gz: EdSurvey/tests/testthat/REF-2-esdfl.R <==
et1REF <- c("",
            "Formula: composite ~ b017451 + dsex ",
            "",
            "Plausible values: 5", 
            "jrrIMax: 1",
            "Weight variable: 'origwt'",
            "Variance method: jackknife", 
            "JK replicates: 62",
            "",
            "Summary Table:",
            "      labels              b017451   dsex  N   WTD_N      PCT   SE(PCT)     MEAN  SE(MEAN)", 
            " A locations Never or hardly ever   Male 10 12.5827 49.06722  7.569623 277.1902  9.653659", 
            " A locations Never or hardly ever Female  9 13.0611 50.93278  7.569623 269.0378  3.584617", 
            " A locations Once every few weeks   Male  8 11.9129 43.99313  3.765086 302.6347  7.582450", 
            " A locations Once every few weeks Female  9 15.1661 56.00687  3.765086 257.9601  4.481766", 
            " A locations    About once a week   Male  5  8.1332 59.85884  3.445449 293.3988  9.217647", 
            " A locations    About once a week Female  4  5.4541 40.14116  3.445449 278.7797  8.946966", 
            " A locations  2 or 3 times a week   Male 11 12.8220 54.36114  5.960610 304.0592 10.285774", 
            " A locations  2 or 3 times a week Female  8 10.7647 45.63886  5.960610 291.0742  8.317934", 
            " A locations            Every day   Male 10 14.4485 68.95013  8.842419 296.7421  4.481794", 
            " A locations            Every day Female  5  6.5065 31.04987  8.842419 324.2656  9.102156", 
            " B locations Never or hardly ever   Male 13 21.6725 77.43608 19.962898 295.0064 15.598551", 
            " B locations Never or hardly ever Female  6  6.3151 22.56392 19.962898 274.6031 10.344199", 
            " B locations Once every few weeks   Male 13 18.3234 76.14318  2.156025 278.5435 18.844505", 
            " B locations Once every few weeks Female  4  5.7410 23.85682  2.156025 292.0952 17.100752", 
            " B locations    About once a week   Male  3  4.7842 34.60192 11.172614 266.4076 18.080846", 
            " B locations    About once a week Female  7  9.0422 65.39808 11.172614 295.1116 20.765073", 
            " B locations  2 or 3 times a week   Male  8 12.9172 52.83735  7.772479 306.8860 28.172189", 
            " B locations  2 or 3 times a week Female  8 11.5299 47.16265  7.772479 297.9851 23.493089", 
            " B locations            Every day   Male  6  9.3770 41.79108  3.040740 304.2102 20.168767", 
            " B locations            Every day Female  8 13.0608 58.20892  3.040740 307.8255 16.584912", 
            " C locations Never or hardly ever   Male  6 10.8124 47.77969  8.112159 304.4941 39.497299", 
            " C locations Never or hardly ever Female  9 11.8173 52.22031  8.112159 284.6628  5.950336", 
            " C locations Once every few weeks   Male  6  7.7506 71.68119 13.890589 278.6115 42.656759", 
            " C locations Once every few weeks Female  4  3.0620 28.31881 13.890589 274.2946  8.732438", 
            " C locations    About once a week   Male  3  5.3106 31.98848  5.364911 293.3708 10.919791", 
            " C locations    About once a week Female  8 11.2910 68.01152  5.364911 313.0450 10.417147", 
            " C locations  2 or 3 times a week   Male  5  6.3631 47.50000  5.421088 284.3908  9.818138", 
            " C locations  2 or 3 times a week Female  5  7.0329 52.50000  5.421088 283.9222 11.715445", 
            " C locations            Every day   Male  7 10.4298 40.97767  5.230350 270.0470  7.455640", 
            " C locations            Every day Female  8 15.0226 59.02233  5.230350 296.9268  7.723949", 
            " D locations Never or hardly ever   Male  6  8.8988 29.06291  7.187947 278.8668 48.293835", 
            " D locations Never or hardly ever Female 11 21.7203 70.93709  7.187947 284.2274 11.060203", 
            " D locations Once every few weeks   Male  9 18.6586 61.90500  7.942009 289.6432 42.618475", 
            " D locations Once every few weeks Female  7 11.4821 38.09500  7.942009 296.3440 38.942394", 
            " D locations    About once a week   Male  6  5.5978 28.32995  9.538735 262.6206 12.639561", 
            " D locations    About once a week Female  9 14.1615 71.67005  9.538735 272.2270 15.980306", 
            " D locations  2 or 3 times a week   Male 12 19.6157 39.92254 11.538978 302.2271 36.999592", 
            " D locations  2 or 3 times a week Female 17 29.5187 60.07746 11.538978 281.6134 24.967995", 
            " D locations            Every day   Male  7  9.2338 32.06025  9.061170 275.6733 36.000387", 
            " D locations            Every day Female 12 19.5676 67.93975  9.061170 268.9318  8.698796"
)

et2REF <- c("",
            "Formula: composite ~ b017451 ",
            "",
            "Plausible values: 5", 
            "jrrIMax: 1",
            "Weight variable: 'origwt'",
            "Variance method: jackknife", 
            "JK replicates: 62",
            "",
            "Summary Table:",
            "             labels              b017451  N WTD_N PCT", 
            "  first E locations Never or hardly ever NA    NA  NA",
            "  first E locations Once every few weeks NA    NA  NA",
            "  first E locations    About once a week NA    NA  NA",
            "  first E locations  2 or 3 times a week NA    NA  NA",
            "  first E locations            Every day NA    NA  NA",
            "        B locations Never or hardly ever 19    28  25",
            "        B locations Once every few weeks 17    24  21", 
            "        B locations    About once a week 10    14  12",
            "        B locations  2 or 3 times a week 16    24  22", 
            "        B locations            Every day 14    22  20",
            "        C locations Never or hardly ever 15    23  25", 
            "        C locations Once every few weeks 10    11  12",
            "        C locations    About once a week 11    17  19", 
            "        C locations  2 or 3 times a week 10    13  15",
            "        C locations            Every day 15    25  29",
            " second E locations Never or hardly ever NA    NA  NA",
            " second E locations Once every few weeks NA    NA  NA",
            " second E locations    About once a week NA    NA  NA",
            " second E locations  2 or 3 times a week NA    NA  NA",
            " second E locations            Every day NA    NA  NA"
)

printREF <- c("an edsurvey.data.frame.list with 4 elements",
              "covs:",
              "       labels",
              "1 A locations",
              "2 B locations",
              "3 C locations",
              "4 D locations",
              "",
              "",
              "Element 1",
              "edsurvey.data.frame for 2005 NAEP National - Primer (Mathematics; Grade 8) in USA",
              "Dimensions: 46 rows and 303 columns.",
              "",
              "There is 1 full sample weight in this edsurvey.data.frame:",
              "  'origwt' with 62 JK replicate weights (the default).",
              "",
              "",
              "There are 6 subject scale(s) or subscale(s) in this edsurvey.data.frame:",
              "'num_oper' subject scale or subscale with 5 plausible values.",
              "",
              "'measurement' subject scale or subscale with 5 plausible values.",
              "",
              "'geometry' subject scale or subscale with 5 plausible values.",
              "",
              "'data_anal_prob' subject scale or subscale with 5 plausible values.",
              "",
              "'algebra' subject scale or subscale with 5 plausible values.",
              "",
              "'composite' subject scale or subscale with 5 plausible values (the default).",
              "",
              "",
              "Omitted Levels: 'Multiple', 'NA', and 'Omitted'",
              "",
              "User Conditions:",
              "scrpsu %in% c(\"5\", \"45\", \"56\") dsex == \"Male\"",
              "",
              "Default Conditions:",
              "tolower(rptsamp) == \"reporting sample\"",
              "Achievement Levels:",
              "Mathematics:",
              "Basic: 262.00",
              "Proficient: 299.00",
              "Advanced: 333.00",
              "",
              "",
              "Element 2",
              "edsurvey.data.frame for 2002 NAEP National - Primer (Mathematics; Grade 8) in USA",
              "Dimensions: 46 rows and 303 columns.",
              "",
              "There is 1 full sample weight in this edsurvey.data.frame:",
              "  'origwt' with 62 JK replicate weights (the default).",
              "",
              "",
              "There are 6 subject scale(s) or subscale(s) in this edsurvey.data.frame:",
              "'num_oper' subject scale or subscale with 5 plausible values.",
              "",
              "'measurement' subject scale or subscale with 5 plausible values.",
              "",
              "'geometry' subject scale or subscale with 5 plausible values.",
              "",
              "'data_anal_prob' subject scale or subscale with 5 plausible values.",
              "",
              "'algebra' subject scale or subscale with 5 plausible values.",
              "",
              "'composite' subject scale or subscale with 5 plausible values (the default).",
              "",
              "",
              "Omitted Levels: 'Multiple', 'NA', and 'Omitted'",
              "",
              "User Conditions:",
              "scrpsu %in% c(\"75\", \"76\", \"78\") dsex == \"Male\"",
              "",
              "Default Conditions:",
              "tolower(rptsamp) == \"reporting sample\"",
              "Achievement Levels:",
              "Mathematics:",
              "Basic: 262.00",
              "Proficient: 299.00",
              "Advanced: 333.00",
              "",
              "",
              "Element 3",
              "edsurvey.data.frame for 2003 NAEP National - Primer (Mathematics; Grade 8) in USA",
              "Dimensions: 28 rows and 303 columns.",
              "",
              "There is 1 full sample weight in this edsurvey.data.frame:",
              "  'origwt' with 62 JK replicate weights (the default).",
              "",
              "",
              "There are 6 subject scale(s) or subscale(s) in this edsurvey.data.frame:",
              "'num_oper' subject scale or subscale with 5 plausible values.",
              "",
              "'measurement' subject scale or subscale with 5 plausible values.",
              "",
              "'geometry' subject scale or subscale with 5 plausible values.",
              "",
              "'data_anal_prob' subject scale or subscale with 5 plausible values.",
              "",
              "'algebra' subject scale or subscale with 5 plausible values.",
              "",
              "'composite' subject scale or subscale with 5 plausible values (the default).",
              "",
              "",
              "Omitted Levels: 'Multiple', 'NA', and 'Omitted'",
              "",
              "User Conditions:",
              "scrpsu %in% 100:200 dsex == \"Male\"",
              "",
              "Default Conditions:",
              "tolower(rptsamp) == \"reporting sample\"",
              "Achievement Levels:",
              "Mathematics:",
              "Basic: 262.00",
              "Proficient: 299.00",
              "Advanced: 333.00",
              "",
              "",
              "Element 4",
              "edsurvey.data.frame for 2005 NAEP National - Primer (Mathematics; Grade 8) in USA",
              "Dimensions: 43 rows and 303 columns.",
              "",
              "There is 1 full sample weight in this edsurvey.data.frame:",
              "  'origwt' with 62 JK replicate weights (the default).",
              "",
              "",
              "There are 6 subject scale(s) or subscale(s) in this edsurvey.data.frame:",
              "'num_oper' subject scale or subscale with 5 plausible values.",
              "",
              "'measurement' subject scale or subscale with 5 plausible values.",
              "",
              "'geometry' subject scale or subscale with 5 plausible values.",
              "",
              "'data_anal_prob' subject scale or subscale with 5 plausible values.",
              "",
              "'algebra' subject scale or subscale with 5 plausible values.",
              "",
              "'composite' subject scale or subscale with 5 plausible values (the default).",
              "",
              "",
              "Omitted Levels: 'Multiple', 'NA', and 'Omitted'",
              "",
              "User Conditions:",
              "scrpsu %in% 201:300 dsex == \"Male\"",
              "",
              "Default Conditions:",
              "tolower(rptsamp) == \"reporting sample\"",
              "Achievement Levels:",
              "Mathematics:",
              "Basic: 262.00",
              "Proficient: 299.00",
              "Advanced: 333.00"
              )
